@@ -624,6 +624,7 @@ class Formatter(Configurable):
     def _format_enum_member_symbol(self, member):
         template = self.get_template("enum_member.html")
         return template.render({
+            'symbol': member,
             'link': member.link,
             'detail': member.formatted_doc,
             'value': str(member.enum_value)})
@@ -808,18 +809,10 @@ class Formatter(Configurable):
         return_value_detail = self._format_return_value_symbol(
             callable_.return_value, callable_)
 
-        tags = {}
-        if callable_.comment:
-            tags = dict(callable_.comment.tags)
-
-        tags.pop('returns', None)
-        tags.pop('topic', None)
-
         out = template.render({'prototype': prototype,
                                'symbol': callable_,
                                'return_value': return_value_detail,
                                'parameters': parameters,
-                               'tags': tags,
                                'extra': callable_.extension_contents})
 
         return out
